--[[ BEGIN GLOBALS ]]--
--[[ BEGIN DEV STUFF ]] --
require('lib/global_lock')
INSPECT = require('lib/inspect')
PERFORMANCEGRAPH = require("lib/performanceGraph")
DEBUG = false

--[[ STATE ]] --
GS = require('lib/hump/gamestate')
STATE = false -- dummy assignment to keep this variable in existance

--[[ LOADER ]] --
LOADER = require('lib/love-loader')
VIDEO, IMAGE, MUSIC, SOUND, FONT = {}, {}, {}, {}, {}
require('src/assets')

--[[ OTHER ]]--
LG = love.graphics

--[[ END GLOBALS ]]--
GLOBAL_lock(_G)


--[[ Black Magick by vrld
	 Lazy (loading), also known as Proxy.
	 Here it is used to load state files from a directory.
	 https://github.com/vrld/moldslife/blob/master/main.lua
	
	 Why didn't I use in the first place? Beats me. It definitely looks simpler.
	 https://love2d.org/wiki/Stateswitcher 
]]-- 
local function Lazy(f)
	return setmetatable({}, {__index = function(t,k) local v = f(k) t[k] = v return v end})
end


function love.load(arg)
	--[[ Exception for easier debugging only ]]--
	GLOBAL_unlock(_G)
	if arg[#arg] == "-debug" then
		require("mobdebug").start()
		DEBUG = true
		PERFORMANCEGRAPH:toggle()
	end
	GLOBAL_lock(_G)
	
	--[[ GAMESTATE ]]--
	STATE = Lazy(function(path) return require('states.' .. path) end)
	GS.registerEvents()
	GS.switch(STATE.LOAD)
	LOADER.start(
		function() -- this anonymous function wrapper is necessary for some reason
			STATE.LOAD.finished = true
		end
	)
end


function love.update(dt)
--	PERFORMANCEGRAPH:preUpdate()
--	PERFORMANCEGRAPH:postUpdate()
end


function love.draw()
--	PERFORMANCEGRAPH:preDraw()
--	PERFORMANCEGRAPH:postDraw()
end


function love.textinput(t)
end


function love.keypressed(key)
end